**Example 1: 删除特殊采集规则配置**



Input: 

```
tccli cls DeleteConfigExtra --cli-unfold-argument  \
    --ConfigExtraId xxxxxxxxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "6ef60bec-0242-43af-bb20-270359fb54a7"
    }
}
```

